// Copyright 2014 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "android_webview/common/aw_switches.h"

namespace switches {

const char kSyncOnDrawHardware[] = "sync-on-draw-hardware";
const char kWebViewSandboxedRenderer[] = "webview-sandboxed-renderer";

// used to enable safebrowsing functionality in webview
const char kWebViewEnableSafeBrowsingSupport[] =
    "webview-enable-safebrowsing-support";

}  // namespace switches
